@@ -22,11 +22,11 @@ import logging
 import logging.config
 import os
 import pprint
+import subprocess  # nosec
 import sys
 from collections import defaultdict
 from copy import copy, deepcopy
 from pathlib import Path
-from subprocess import check_call  # nosec
 from typing import Any, Collection, Dict, List, Optional, Set, Tuple, Type, Union, cast
 
 import jsonschema
@@ -68,22 +68,20 @@ from aea.configurations.constants import (
     SIGNING_PROTOCOL,
     SKILLS,
     STATE_UPDATE_PROTOCOL,
-    VENDOR,
 )
 from aea.configurations.loader import ConfigLoader, load_component_configuration
+from aea.configurations.manager import (
+    AgentConfigManager,
+    find_component_directory_from_component_id,
+)
 from aea.configurations.pypi import is_satisfiable, merge_dependencies
-from aea.crypto.helpers import verify_or_create_private_keys
+from aea.crypto.helpers import private_key_verify_or_create
 from aea.crypto.ledger_apis import DEFAULT_CURRENCY_DENOMINATIONS
 from aea.crypto.wallet import Wallet
 from aea.decision_maker.base import DecisionMakerHandler
 from aea.error_handler.base import AbstractErrorHandler
 from aea.exceptions import AEAException, AEAValidationError, enforce
-from aea.helpers.base import (
-    ensure_dir,
-    find_topological_order,
-    load_env_file,
-    load_module,
-)
+from aea.helpers.base import find_topological_order, load_env_file, load_module
 from aea.helpers.exception_policy import ExceptionPolicyEnum
 from aea.helpers.install_dependency import install_dependency
 from aea.helpers.logging import AgentLoggerAdapter, WithLogger, get_logger
@@ -780,7 +778,6 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
             configuration.author,
             configuration.name,
         )
-        ensure_dir(configuration.build_directory)
 
     def add_component_instance(self, component: Component) -> "AEABuilder":
         """
@@ -903,15 +900,18 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
         self.remove_component(ComponentId(ComponentType.CONTRACT, public_id))
         return self
 
-    def call_all_build_entrypoints(self):
+    def call_all_build_entrypoints(self, root_dir: str = "."):
         """Call all the build entrypoints."""
         for config in self._package_dependency_manager._dependencies.values():  # type: ignore # pylint: disable=protected-access
             self.run_build_for_component_configuration(config, logger=self.logger)
 
+        target_directory = os.path.abspath(
+            os.path.join(root_dir, self.AEA_CLASS.get_build_dir())
+        )
+
         if self._build_entrypoint:
             self.logger.info("Building AEA package...")
             source_directory = "."
-            target_directory = os.path.abspath(self.AEA_CLASS.get_build_dir())
             build_entrypoint = cast(str, self._build_entrypoint)
             self._run_build_entrypoint(
                 build_entrypoint, source_directory, target_directory, logger=self.logger
@@ -962,15 +962,37 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
         command = [sys.executable, build_entrypoint, target_directory]
         command_str = " ".join(command)
         if logger:
-            logger.info(f"Running command '{command_str}'")
-        try:
-            check_call(
-                command, cwd=source_directory, timeout=cls.BUILD_TIMEOUT
-            )  # nosec
-        except Exception as e:
+            logger.info(f"Running command '{command_str}'...")
+        stdout, stderr, code = cls._run_in_subprocess(command, source_directory)
+        if code == 0:
+            if logger:
+                logger.info(f"Command '{command_str}' succeded with output:\n{stdout}")
+        else:
             raise AEAException(
-                f"An error occurred while running command '{command_str}': {str(e)}"
-            ) from e
+                f"An error occurred while running command '{command_str}':\n{stderr}"
+            )
+
+    @classmethod
+    def _run_in_subprocess(
+        cls, command: List[str], source_directory: str
+    ) -> Tuple[str, str, int]:
+        """
+        Run in subprocess.
+
+        :return: stdout, stderr, code
+        """
+        res = subprocess.run(  # nosec
+            command,
+            cwd=source_directory,
+            check=False,
+            timeout=cls.BUILD_TIMEOUT,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+        )
+        code = res.returncode
+        stdout = res.stdout.decode("utf-8")
+        stderr = res.stderr.decode("utf-8")
+        return stdout, stderr, code
 
     def _build_identity_from_wallet(self, wallet: Wallet) -> Identity:
         """
@@ -989,13 +1011,13 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
             identity = Identity(
                 self._name,
                 addresses=wallet.addresses,
-                default_address_key=self._get_default_ledger(),
+                default_address_key=self.get_default_ledger(),
             )
         else:
             identity = Identity(
                 self._name,
-                address=wallet.addresses[self._get_default_ledger()],
-                default_address_key=self._get_default_ledger(),
+                address=wallet.addresses[self.get_default_ledger()],
+                default_address_key=self.get_default_ledger(),
             )
         return identity
 
@@ -1117,7 +1139,7 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
         self._build_called = True
         return aea
 
-    def _get_default_ledger(self) -> str:
+    def get_default_ledger(self) -> str:
         """
         Return default ledger.
 
@@ -1330,42 +1352,18 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
                     f"Conflict on package {pkg_name}: specifier set '{dep_info.version}' not satisfiable."
                 )
 
-    @staticmethod
-    def find_component_directory_from_component_id(
-        aea_project_directory: Path, component_id: ComponentId
-    ) -> Path:
-        """Find a component directory from component id."""
-        # search in vendor first
-        vendor_package_path = (
-            aea_project_directory
-            / VENDOR
-            / component_id.public_id.author
-            / component_id.component_type.to_plural()
-            / component_id.public_id.name
-        )
-        if vendor_package_path.exists() and vendor_package_path.is_dir():
-            return vendor_package_path
-
-        # search in custom packages.
-        custom_package_path = (
-            aea_project_directory
-            / component_id.component_type.to_plural()
-            / component_id.public_id.name
-        )
-        if custom_package_path.exists() and custom_package_path.is_dir():
-            return custom_package_path
-
-        raise ValueError("Package {} not found.".format(component_id))
-
-    @staticmethod
-    def _try_to_load_agent_configuration_file(aea_project_path: Path) -> None:
+    @classmethod
+    def try_to_load_agent_configuration_file(
+        cls, aea_project_path: Union[str, Path]
+    ) -> AgentConfig:
         """Try to load the agent configuration file.."""
         try:
-            configuration_file_path = Path(aea_project_path, DEFAULT_AEA_CONFIG_FILE)
+            aea_project_path = Path(aea_project_path)
+            configuration_file_path = cls.get_configuration_file_path(aea_project_path)
             with configuration_file_path.open(mode="r", encoding="utf-8") as fp:
                 loader = ConfigLoader.from_configuration_type(PackageType.AGENT)
                 agent_configuration = loader.load(fp)
-                logging.config.dictConfig(agent_configuration.logging_config)  # type: ignore
+                return agent_configuration
         except FileNotFoundError:  # pragma: nocover
             raise ValueError(
                 "Agent configuration file '{}' not found in the current directory.".format(
@@ -1486,8 +1484,8 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
             agent_configuration.component_configurations
         )
 
+    @staticmethod
     def _find_import_order(
-        self,
         component_ids: List[ComponentId],
         aea_project_path: Path,
         skip_consistency_check: bool,
@@ -1506,7 +1504,7 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
             ComponentId, Set[ComponentId]
         ] = defaultdict(set)
         for component_id in component_ids:
-            component_path = self.find_component_directory_from_component_id(
+            component_path = find_component_directory_from_component_id(
                 aea_project_path, component_id
             )
             configuration = load_component_configuration(
@@ -1537,7 +1535,10 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
 
     @classmethod
     def from_aea_project(
-        cls, aea_project_path: PathLike, skip_consistency_check: bool = False
+        cls,
+        aea_project_path: PathLike,
+        skip_consistency_check: bool = False,
+        create_keys: bool = True,
     ) -> "AEABuilder":
         """
         Construct the builder from an AEA project.
@@ -1551,48 +1552,31 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
 
         :param aea_project_path: path to the AEA project.
         :param skip_consistency_check: if True, the consistency check are skipped.
+        :param create_keys: if True, create keys, otherwise just verify
         :return: an AEABuilder.
         """
         aea_project_path = Path(aea_project_path)
-        cls._try_to_load_agent_configuration_file(aea_project_path)
-        verify_or_create_private_keys(
-            aea_project_path=aea_project_path, exit_on_error=False
-        )
-        builder = AEABuilder(with_default_packages=False)
+        cls.try_to_load_agent_configuration_file(aea_project_path)
 
         load_env_file(str(aea_project_path / DEFAULT_ENV_DOTFILE))
 
-        # load agent configuration file
-        configuration_file = cls.get_configuration_file_path(aea_project_path)
-        agent_configuration = cls.loader.load(configuration_file.open())
+        # check and create missing, do not replace env variables. updates config
+        AgentConfigManager.verify_or_create_private_keys(
+            aea_project_path,
+            substitude_env_vars=False,
+            private_key_helper=private_key_verify_or_create,
+            create_keys=create_keys,
+        ).dump_config()
 
-        builder.set_from_configuration(
-            agent_configuration, aea_project_path, skip_consistency_check
-        )
-        return builder
+        # just validate
+        agent_configuration = AgentConfigManager.verify_or_create_private_keys(
+            aea_project_path,
+            substitude_env_vars=True,
+            private_key_helper=private_key_verify_or_create,
+            create_keys=create_keys,
+        ).agent_config
 
-    @classmethod
-    def from_config_json(
-        cls,
-        json_data: List[Dict],
-        aea_project_path: PathLike,
-        skip_consistency_check: bool = False,
-    ) -> "AEABuilder":
-        """
-        Load agent configuration for alreaady provided json data.
-
-        :param json_data: list of dicts with agent configuration
-        :param aea_project_path: path to project root
-        :param skip_consistency_check: skip consistency check on configs load.
-
-        :return: AEABuilder instance
-        """
-        aea_project_path = Path(aea_project_path)
         builder = AEABuilder(with_default_packages=False)
-
-        # load agent configuration file
-        agent_configuration = cls.loader.load_agent_config_from_json(json_data)
-
         builder.set_from_configuration(
             agent_configuration, aea_project_path, skip_consistency_check
         )
@@ -1663,6 +1647,7 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
             new_configuration.component_id, {}
         )
         new_configuration.update(custom_config)
+
         return new_configuration
 
     def _add_components_of_type(
@@ -1693,7 +1678,7 @@ class AEABuilder(WithLogger):  # pylint: disable=too-many-public-methods
                 component_ids, aea_project_path, skip_consistency_check
             )
         for component_id in import_order:
-            component_path = self.find_component_directory_from_component_id(
+            component_path = find_component_directory_from_component_id(
                 aea_project_path, component_id
             )
             self.add_component(
