@@ -23,5 +23,5 @@
 from aea.cli.core import cli
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     cli(prog_name="aea")  # pragma: no cover
