@@ -89,10 +89,16 @@ def contract(ctx: Context, contract_name: str) -> None:
 
 @scaffold.command()
 @click.argument("protocol_name", type=str, required=True)
+@click.option("-y", "--yes", is_flag=True, default=False)
 @pass_ctx
-def protocol(ctx: Context, protocol_name: str):
+def protocol(ctx: Context, protocol_name: str, yes: bool):
     """Add a protocol scaffolding to the configuration file and agent."""
-    scaffold_item(ctx, PROTOCOL, protocol_name)
+    if yes or click.confirm(
+        "We highly recommend auto-generating protocols with the aea generate command. Do you really want to continue scaffolding?"
+    ):
+        scaffold_item(ctx, PROTOCOL, protocol_name)
+    else:
+        click.echo("Aborted. Exit")  # pragma: nocover
 
 
 @scaffold.command()
@@ -250,7 +256,7 @@ def _scaffold_non_package_item(
     try:
         # copy the item package into the agent project.
         src = Path(os.path.join(AEA_DIR, aea_dir, "scaffold.py"))
-        logger.debug(f"Copying error handler. src={src} dst={dest}")
+        logger.debug(f"Copying {type_name}. src={src} dst={dest}")
         shutil.copyfile(src, dest)
 
         # add the item to the configurations.
