@@ -105,7 +105,8 @@ class Context:
         if not path.exists():
             path = Path(item_type_plural, public_id.name, default_config_file_name)
         config_loader = ConfigLoader.from_configuration_type(item_type)
-        config = config_loader.load(path.open())
+        with path.open() as fp:
+            config = config_loader.load(fp)
         deps = cast(Dependencies, config.dependencies)
         return deps
 
