@@ -19,8 +19,7 @@
 
 """This module contains the scaffold contract definition."""
 
-from typing import Any, Dict
-
+from aea.common import JSONLike
 from aea.configurations.base import PublicId
 from aea.contracts.base import Contract
 from aea.crypto.base import LedgerApi
@@ -34,7 +33,7 @@ class MyScaffoldContract(Contract):
     @classmethod
     def get_raw_transaction(
         cls, ledger_api: LedgerApi, contract_address: str, **kwargs
-    ) -> Dict[str, Any]:
+    ) -> JSONLike:
         """
         Handler method for the 'GET_RAW_TRANSACTION' requests.
 
@@ -50,7 +49,7 @@ class MyScaffoldContract(Contract):
     @classmethod
     def get_raw_message(
         cls, ledger_api: LedgerApi, contract_address: str, **kwargs
-    ) -> Dict[str, Any]:
+    ) -> bytes:
         """
         Handler method for the 'GET_RAW_MESSAGE' requests.
 
@@ -66,7 +65,7 @@ class MyScaffoldContract(Contract):
     @classmethod
     def get_state(
         cls, ledger_api: LedgerApi, contract_address: str, **kwargs
-    ) -> Dict[str, Any]:
+    ) -> JSONLike:
         """
         Handler method for the 'GET_STATE' requests.
 
