@@ -22,11 +22,9 @@
 from aea.crypto.cosmos import CosmosCrypto
 from aea.crypto.ethereum import EthereumCrypto
 from aea.crypto.fetchai import FetchAICrypto
-from aea.crypto.registries import (
-    register_crypto,
-    register_faucet_api,
-    register_ledger_api,
-)  # noqa
+from aea.crypto.registries import register_crypto  # noqa
+from aea.crypto.registries import register_faucet_api, register_ledger_api
+
 
 register_crypto(
     id_=FetchAICrypto.identifier, entry_point="aea.crypto.fetchai:FetchAICrypto"
