@@ -19,10 +19,9 @@
 
 """This module contains class representations corresponding to every custom type in the protocol specification."""
 
-import pickle  # nosec
-from typing import Any, Dict
-
+from aea.common import JSONLike
 from aea.exceptions import enforce
+from aea.helpers.serializers import DictProtobufStructSerializer
 from aea.helpers.transaction.base import RawMessage as BaseRawMessage
 from aea.helpers.transaction.base import RawTransaction as BaseRawTransaction
 from aea.helpers.transaction.base import State as BaseState
@@ -37,7 +36,7 @@ class Kwargs:
     """This class represents an instance of Kwargs."""
 
     def __init__(
-        self, body: Dict[str, Any],
+        self, body: JSONLike,
     ):
         """Initialise an instance of RawTransaction."""
         self._body = body
@@ -45,8 +44,6 @@ class Kwargs:
 
     def _check_consistency(self) -> None:
         """Check consistency of the object."""
-        if self._body is None:
-            raise ValueError("body must not be None")
         enforce(
             isinstance(self._body, dict)
             and all([isinstance(key, str) for key in self._body.keys()]),
@@ -54,7 +51,7 @@ class Kwargs:
         )
 
     @property
-    def body(self) -> Dict[str, Any]:
+    def body(self) -> JSONLike:
         """Get the body."""
         return self._body
 
@@ -69,8 +66,9 @@ class Kwargs:
         :param kwargs_object: an instance of this class to be encoded in the protocol buffer object.
         :return: None
         """
-        kwargs_bytes = pickle.dumps(kwargs_object)  # nosec
-        kwargs_protobuf_object.kwargs = kwargs_bytes
+        kwargs_protobuf_object.kwargs = DictProtobufStructSerializer.encode(
+            kwargs_object.body
+        )
 
     @classmethod
     def decode(cls, kwargs_protobuf_object) -> "Kwargs":
@@ -82,8 +80,8 @@ class Kwargs:
         :param kwargs_protobuf_object: the protocol buffer object whose type corresponds with this class.
         :return: A new instance of this class that matches the protocol buffer object in the 'kwargs_protobuf_object' argument.
         """
-        kwargs = pickle.loads(kwargs_protobuf_object.kwargs)  # nosec
-        return kwargs
+        kwargs = DictProtobufStructSerializer.decode(kwargs_protobuf_object.kwargs)
+        return cls(kwargs)
 
     def __eq__(self, other):
         """Check equality."""
