@@ -35,16 +35,24 @@ from typing import Dict, List, Set
 import yaml
 
 from aea.configurations.base import PackageId, PackageType, PublicId
+from aea.configurations.constants import (
+    AGENTS,
+    DEFAULT_AEA_CONFIG_FILE,
+    DEFAULT_CONNECTION_CONFIG_FILE,
+    DEFAULT_CONTRACT_CONFIG_FILE,
+    DEFAULT_PROTOCOL_CONFIG_FILE,
+    DEFAULT_SKILL_CONFIG_FILE,
+)
 
 
 DEFAULT_CONFIG_FILE_PATHS = []  # type: List[Path]
 
 CONFIG_FILE_NAMES = [
-    "aea-config.yaml",
-    "skill.yaml",
-    "connection.yaml",
-    "contract.yaml",
-    "protocol.yaml",
+    DEFAULT_AEA_CONFIG_FILE,
+    DEFAULT_SKILL_CONFIG_FILE,
+    DEFAULT_CONNECTION_CONFIG_FILE,
+    DEFAULT_CONTRACT_CONFIG_FILE,
+    DEFAULT_PROTOCOL_CONFIG_FILE,
 ]  # type: List[str]
 
 
@@ -75,7 +83,12 @@ class DependencyNotFound(Exception):
 def find_all_configuration_files():
     """Find all configuration files."""
     packages_dir = Path("packages")
-    return list(chain(packages_dir.glob("*/*/*/*.yaml"), default_config_file_paths()))
+    config_files = [
+        path
+        for path in packages_dir.glob("*/*/*/*.yaml")
+        if any([file in str(path) for file in CONFIG_FILE_NAMES])
+    ]
+    return list(chain(config_files, default_config_file_paths()))
 
 
 def default_config_file_paths():
@@ -109,13 +122,7 @@ def get_public_id_from_yaml(configuration_file: Path):
 def find_all_packages_ids() -> Set[PackageId]:
     """Find all packages ids."""
     package_ids: Set[PackageId] = set()
-    packages_dir = Path("packages")
-    config_files = [
-        path
-        for path in packages_dir.glob("*/*/*/*.yaml")
-        if any([file in str(path) for file in CONFIG_FILE_NAMES])
-    ]
-    for configuration_file in chain(config_files, default_config_file_paths()):
+    for configuration_file in find_all_configuration_files():
         package_type = PackageType(configuration_file.parts[-3][:-1])
         package_public_id = get_public_id_from_yaml(configuration_file)
         package_id = PackageId(package_type, package_public_id)
@@ -143,7 +150,7 @@ def unified_yaml_load(configuration_file: Path) -> Dict:
     """
     package_type = configuration_file.parent.parent.name
     with configuration_file.open() as fp:
-        if package_type != "agents":
+        if package_type != AGENTS:
             return yaml.safe_load(fp)
         # when it is an agent configuration file,
         # we are interested only in the first page of the YAML,
