@@ -31,7 +31,7 @@ import time
 from functools import WRAPPER_ASSIGNMENTS, wraps
 from pathlib import Path
 from types import FunctionType, MethodType
-from typing import Callable, Dict, List, Optional, Sequence, Tuple, cast
+from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union, cast
 from unittest.mock import patch
 
 import docker as docker
@@ -49,10 +49,11 @@ from aea.configurations.base import DEFAULT_CONTRACT_CONFIG_FILE as CONTRACT_YAM
 from aea.configurations.base import DEFAULT_PROTOCOL_CONFIG_FILE as PROTOCOL_YAML
 from aea.configurations.base import DEFAULT_SKILL_CONFIG_FILE as SKILL_YAML
 from aea.configurations.base import PublicId
-from aea.configurations.constants import DEFAULT_LEDGER
+from aea.configurations.constants import DEFAULT_LEDGER, PRIVATE_KEY_PATH_SCHEMA
 from aea.configurations.loader import load_component_configuration
 from aea.connections.base import Connection
 from aea.contracts.base import Contract, contract_registry
+from aea.crypto.base import Crypto
 from aea.crypto.cosmos import DEFAULT_ADDRESS as COSMOS_DEFAULT_ADDRESS
 from aea.crypto.cosmos import _COSMOS
 from aea.crypto.ethereum import DEFAULT_ADDRESS as ETHEREUM_DEFAULT_ADDRESS
@@ -63,10 +64,10 @@ from aea.crypto.ethereum import (
 from aea.crypto.ethereum import EthereumApi, EthereumCrypto, _ETHEREUM
 from aea.crypto.fetchai import DEFAULT_ADDRESS as FETCHAI_DEFAULT_ADDRESS
 from aea.crypto.fetchai import _FETCHAI
-from aea.crypto.helpers import PRIVATE_KEY_PATH_SCHEMA
 from aea.crypto.ledger_apis import DEFAULT_LEDGER_CONFIGS
 from aea.crypto.registries import ledger_apis_registry, make_crypto
 from aea.crypto.wallet import CryptoStore
+from aea.helpers.base import CertRequest, SimpleId
 from aea.identity.base import Identity
 from aea.test_tools.click_testing import CliRunner as ImportedCliRunner
 from aea.test_tools.constants import DEFAULT_AUTHOR
@@ -78,6 +79,7 @@ from packages.fetchai.connections.p2p_libp2p.connection import (
     LIBP2P_NODE_MODULE_NAME,
     MultiAddr,
     P2PLibp2pConnection,
+    POR_DEFAULT_SERVICE_ID,
 )
 from packages.fetchai.connections.p2p_libp2p_client.connection import (
     P2PLibp2pClientConnection,
@@ -189,24 +191,30 @@ COSMOS_P2P_ADDRESS = "/dns4/127.0.0.1/tcp/9000/p2p/16Uiu2HAmAzvu5uNbcnD2qaqrkSUL
 FETCHAI_P2P_ADDRESS = "/dns4/127.0.0.1/tcp/9000/p2p/16Uiu2HAmLBCAqHL8SuFosyDhAKYsLKXBZBWXBsB9oFw2qU4Kckun"  # relates to NON_FUNDED_FETCHAI_PRIVATE_KEY_1
 NON_GENESIS_CONFIG = {
     "delegate_uri": "127.0.0.1:11001",
-    "entry_peers": [COSMOS_P2P_ADDRESS],
+    "entry_peers": [FETCHAI_P2P_ADDRESS],
     "local_uri": "127.0.0.1:9001",
     "log_file": "libp2p_node.log",
     "public_uri": "127.0.0.1:9001",
-    "ledger_id": "cosmos",
+    "ledger_id": "fetchai",
 }
 NON_GENESIS_CONFIG_TWO = {
     "delegate_uri": "127.0.0.1:11002",
-    "entry_peers": [COSMOS_P2P_ADDRESS],
+    "entry_peers": [FETCHAI_P2P_ADDRESS],
     "local_uri": "127.0.0.1:9002",
     "log_file": "libp2p_node.log",
     "public_uri": "127.0.0.1:9002",
-    "ledger_id": "cosmos",
+    "ledger_id": "fetchai",
 }
 PUBLIC_DHT_P2P_MADDR_1 = "/dns4/acn.fetch.ai/tcp/9000/p2p/16Uiu2HAkw1ypeQYQbRFV5hKUxGRHocwU5ohmVmCnyJNg36tnPFdx"
 PUBLIC_DHT_P2P_MADDR_2 = "/dns4/acn.fetch.ai/tcp/9001/p2p/16Uiu2HAmVWnopQAqq4pniYLw44VRvYxBUoRHqjz1Hh2SoCyjbyRW"
 PUBLIC_DHT_DELEGATE_URI_1 = "acn.fetch.ai:11000"
 PUBLIC_DHT_DELEGATE_URI_2 = "acn.fetch.ai:11001"
+PUBLIC_DHT_P2P_PUBLIC_KEY_1 = (
+    "0217a59bd805c310aca4febe0e99ce22ee3712ae085dc1e5630430b1e15a584bb7"
+)
+PUBLIC_DHT_P2P_PUBLIC_KEY_2 = (
+    "03fa7cfae1037cba5218f0f5743802eced8de3247c55ecebaae46c7d3679e3f91d"
+)
 
 # testnets
 COSMOS_TESTNET_CONFIG = {"address": COSMOS_DEFAULT_ADDRESS}
@@ -220,7 +228,7 @@ FETCHAI_TESTNET_CONFIG = {"address": FETCHAI_DEFAULT_ADDRESS}
 # common public ids used in the tests
 UNKNOWN_PROTOCOL_PUBLIC_ID = PublicId("unknown_author", "unknown_protocol", "0.1.0")
 UNKNOWN_CONNECTION_PUBLIC_ID = PublicId("unknown_author", "unknown_connection", "0.1.0")
-MY_FIRST_AEA_PUBLIC_ID = PublicId.from_str("fetchai/my_first_aea:0.16.0")
+MY_FIRST_AEA_PUBLIC_ID = PublicId.from_str("fetchai/my_first_aea:0.17.0")
 
 DUMMY_SKILL_PATH = os.path.join(CUR_PATH, "data", "dummy_skill", SKILL_YAML)
 
@@ -228,6 +236,7 @@ MAX_FLAKY_RERUNS = 3
 MAX_FLAKY_RERUNS_ETH = 1
 MAX_FLAKY_RERUNS_INTEGRATION = 1
 
+PACKAGES_DIR = os.path.join(ROOT_DIR, "packages")
 FETCHAI_PREF = os.path.join(ROOT_DIR, "packages", "fetchai")
 PROTOCOL_SPECS_PREF_1 = os.path.join(ROOT_DIR, "examples", "protocol_specification_ex")
 PROTOCOL_SPECS_PREF_2 = os.path.join(ROOT_DIR, "tests", "data")
@@ -774,6 +783,14 @@ def _make_stub_connection(input_file_path: str, output_file_path: str):
     return connection
 
 
+def _process_cert(key: Crypto, cert: CertRequest):
+    # must match aea/cli/issue_certificates.py:_process_certificate
+    assert cert.public_key is not None
+    message = cert.get_message(cert.public_key)
+    signature = key.sign_message(message).encode("ascii").hex()
+    Path(cert.save_path).write_bytes(signature.encode("ascii"))
+
+
 def _make_libp2p_connection(
     port: int = 10234,
     host: str = "127.0.0.1",
@@ -783,16 +800,35 @@ def _make_libp2p_connection(
     delegate_port: int = 11234,
     delegate_host: str = "127.0.0.1",
     node_key_file: Optional[str] = None,
-    agent_address: Optional[Address] = None,
+    agent_key: Optional[Crypto] = None,
     build_directory: Optional[str] = None,
+    peer_registration_delay: str = "0.0",
 ) -> P2PLibp2pConnection:
     log_file = "libp2p_node_{}.log".format(port)
     if os.path.exists(log_file):
         os.remove(log_file)
-    address = agent_address
-    if address is None:
-        address = make_crypto(COSMOS).address
-    identity = Identity("", address=address)
+    key = agent_key
+    if key is None:
+        key = make_crypto(DEFAULT_LEDGER)
+    identity = Identity("", address=key.address)
+    conn_crypto_store = None
+    if node_key_file is not None:
+        conn_crypto_store = CryptoStore({DEFAULT_LEDGER: node_key_file})
+    else:
+        node_key = make_crypto(DEFAULT_LEDGER)
+        node_key_path = f"./{node_key.public_key}.txt"
+        with open(node_key_path, "wb") as f:
+            node_key.dump(f)
+        conn_crypto_store = CryptoStore({DEFAULT_LEDGER: node_key_path})
+    cert_request = CertRequest(
+        conn_crypto_store.public_keys[DEFAULT_LEDGER],
+        POR_DEFAULT_SERVICE_ID,
+        key.identifier,
+        "2021-01-01",
+        "2021-01-02",
+        f"./{key.address}_cert.txt",
+    )
+    _process_cert(key, cert_request)
     if not build_directory:
         build_directory = os.getcwd()
     if relay and delegate:
@@ -803,8 +839,10 @@ def _make_libp2p_connection(
             entry_peers=entry_peers,
             log_file=log_file,
             delegate_uri="{}:{}".format(delegate_host, delegate_port),
+            peer_registration_delay=peer_registration_delay,
             connection_id=P2PLibp2pConnection.connection_id,
             build_directory=build_directory,
+            cert_requests=[cert_request],
         )
     elif relay and not delegate:
         configuration = ConnectionConfig(
@@ -813,8 +851,10 @@ def _make_libp2p_connection(
             public_uri="{}:{}".format(host, port),
             entry_peers=entry_peers,
             log_file=log_file,
+            peer_registration_delay=peer_registration_delay,
             connection_id=P2PLibp2pConnection.connection_id,
             build_directory=build_directory,
+            cert_requests=[cert_request],
         )
     else:
         configuration = ConnectionConfig(
@@ -822,30 +862,49 @@ def _make_libp2p_connection(
             local_uri="{}:{}".format(host, port),
             entry_peers=entry_peers,
             log_file=log_file,
+            peer_registration_delay=peer_registration_delay,
             connection_id=P2PLibp2pConnection.connection_id,
             build_directory=build_directory,
+            cert_requests=[cert_request],
         )
     if not os.path.exists(os.path.join(build_directory, LIBP2P_NODE_MODULE_NAME)):
         build_node(build_directory)
-    connection = P2PLibp2pConnection(configuration=configuration, identity=identity)
+    connection = P2PLibp2pConnection(
+        configuration=configuration, identity=identity, crypto_store=conn_crypto_store
+    )
     return connection
 
 
 def _make_libp2p_client_connection(
-    node_port: int = 11234, node_host: str = "127.0.0.1", uri: Optional[str] = None,
+    peer_public_key: str,
+    node_port: int = 11234,
+    node_host: str = "127.0.0.1",
+    uri: Optional[str] = None,
+    ledger_api_id: Union[SimpleId, str] = DEFAULT_LEDGER,
 ) -> P2PLibp2pClientConnection:
-    crypto = make_crypto(COSMOS)
+    crypto = make_crypto(ledger_api_id)
     identity = Identity("", address=crypto.address)
+    cert_request = CertRequest(
+        peer_public_key,
+        POR_DEFAULT_SERVICE_ID,
+        ledger_api_id,
+        "2021-01-01",
+        "2021-01-02",
+        f"./{crypto.address}_cert.txt",
+    )
+    _process_cert(crypto, cert_request)
     configuration = ConnectionConfig(
         client_key_file=None,
         nodes=[
             {
                 "uri": str(uri)
                 if uri is not None
-                else "{}:{}".format(node_host, node_port)
-            }
+                else "{}:{}".format(node_host, node_port),
+                "public_key": peer_public_key,
+            },
         ],
         connection_id=P2PLibp2pClientConnection.connection_id,
+        cert_requests=[cert_request],
     )
     return P2PLibp2pClientConnection(configuration=configuration, identity=identity)
 
