@@ -44,6 +44,7 @@ from aea.cli.utils.package_utils import (
     _override_ledger_configurations,
     find_item_in_distribution,
     find_item_locally,
+    get_dotted_package_path_unified,
     get_package_path_unified,
     get_wallet_from_context,
     is_distributed_item,
@@ -298,7 +299,7 @@ class FindItemLocallyTestCase(TestCase):
     )
     def test_find_item_locally_bad_config(self, *mocks):
         """Test find_item_locally for bad config result."""
-        public_id = PublicIdMock.from_str("fetchai/echo:0.12.0")
+        public_id = PublicIdMock.from_str("fetchai/echo:0.13.0")
         with self.assertRaises(ClickException) as cm:
             find_item_locally(ContextMock(), "skill", public_id)
 
@@ -312,7 +313,7 @@ class FindItemLocallyTestCase(TestCase):
     )
     def test_find_item_locally_cant_find(self, from_conftype_mock, *mocks):
         """Test find_item_locally for can't find result."""
-        public_id = PublicIdMock.from_str("fetchai/echo:0.12.0")
+        public_id = PublicIdMock.from_str("fetchai/echo:0.13.0")
         with self.assertRaises(ClickException) as cm:
             find_item_locally(ContextMock(), "skill", public_id)
 
@@ -331,7 +332,7 @@ class FindItemInDistributionTestCase(TestCase):
     )
     def testfind_item_in_distribution_bad_config(self, *mocks):
         """Test find_item_in_distribution for bad config result."""
-        public_id = PublicIdMock.from_str("fetchai/echo:0.12.0")
+        public_id = PublicIdMock.from_str("fetchai/echo:0.13.0")
         with self.assertRaises(ClickException) as cm:
             find_item_in_distribution(ContextMock(), "skill", public_id)
 
@@ -340,7 +341,7 @@ class FindItemInDistributionTestCase(TestCase):
     @mock.patch("aea.cli.utils.package_utils.Path.exists", return_value=False)
     def testfind_item_in_distribution_not_found(self, *mocks):
         """Test find_item_in_distribution for not found result."""
-        public_id = PublicIdMock.from_str("fetchai/echo:0.12.0")
+        public_id = PublicIdMock.from_str("fetchai/echo:0.13.0")
         with self.assertRaises(ClickException) as cm:
             find_item_in_distribution(ContextMock(), "skill", public_id)
 
@@ -354,7 +355,7 @@ class FindItemInDistributionTestCase(TestCase):
     )
     def testfind_item_in_distribution_cant_find(self, from_conftype_mock, *mocks):
         """Test find_item_locally for can't find result."""
-        public_id = PublicIdMock.from_str("fetchai/echo:0.12.0")
+        public_id = PublicIdMock.from_str("fetchai/echo:0.13.0")
         with self.assertRaises(ClickException) as cm:
             find_item_in_distribution(ContextMock(), "skill", public_id)
 
@@ -438,6 +439,22 @@ def test_get_package_path_unified(mock_present, mock_path, vendor):
     assert result == "some_path"
 
 
+@mock.patch("aea.cli.utils.package_utils.get_package_path", return_value="some_path")
+@mock.patch("aea.cli.utils.package_utils.is_item_present")
+@pytest.mark.parametrize("vendor", [True, False])
+def test_get_dotted_package_path_unified(mock_present, mock_path, vendor):
+    """Test 'get_package_path_unified'."""
+    contex_mock = mock.MagicMock()
+    contex_mock.cwd = "."
+    contex_mock.agent_config.author = "some_author" if vendor else "another_author"
+    mock_present.return_value = vendor
+    public_id_mock = mock.MagicMock(author="some_author")
+    result = get_dotted_package_path_unified(
+        contex_mock, "some_component_type", public_id_mock
+    )
+    assert result == "some_path"
+
+
 @mock.patch("aea.cli.utils.package_utils.is_item_present", return_value=False)
 @pytest.mark.parametrize("vendor", [True, False])
 def test_is_item_present_unified(mock_, vendor):
