@@ -61,7 +61,7 @@ connections: []
 contracts: []
 protocols: []
 skills: []
-default_connection: fetchai/stub:0.13.0
+default_connection: fetchai/stub:0.14.0
 default_ledger: cosmos
 private_key_paths:
     cosmos: tests/data/cosmos_private_key.txt
@@ -440,6 +440,7 @@ def test_agent_configuration_dump_multipage_fails_bad_component_configuration():
     ] = "not in specs!"
     fp = io.StringIO()
     with pytest.raises(
-        ValueError, match="Configuration of component .* is not valid..*'BAD FIELD'"
+        ValueError,
+        match="Configuration of component .* is not valid. ExtraPropertiesError: properties not expected: BAD FIELD",
     ):
         loader.dump(agent_config, fp)
