@@ -17,6 +17,7 @@
 #
 # ------------------------------------------------------------------------------
 """This module contains the tests for the helper module."""
+import datetime
 import os
 import platform
 import re
@@ -26,15 +27,19 @@ from copy import copy
 from pathlib import Path
 from subprocess import Popen  # nosec
 from tempfile import TemporaryDirectory
-from typing import Dict, Set
+from typing import Dict, Optional, Set
 from unittest.mock import patch
 
 import pytest
+from packaging.version import Version
 
 from aea.exceptions import AEAEnforceError
 from aea.helpers.base import (
+    CertRequest,
     MaxRetriesError,
     RegexConstrainedString,
+    compute_specifier_from_version,
+    dict_to_path_value,
     ensure_dir,
     exception_log_and_reraise,
     find_topological_order,
@@ -259,6 +264,23 @@ def test_recursive_update_negative_different_type():
         recursive_update(to_update, new_values)
 
 
+def test_recursive_update_new_fields():
+    """Test the 'recursive update' utility, with new fields."""
+    # here we try to update an integer with a boolean - it raises error.
+    to_update = dict(subdict=dict(to_update=1))
+    new_values = dict(subdict=dict(to_update2=False))
+
+    with pytest.raises(
+        ValueError,
+        match="Key 'to_update2' is not contained in the dictionary to update.",
+    ):
+        recursive_update(to_update, new_values)
+    assert "to_update2" not in to_update["subdict"]
+
+    recursive_update(to_update, new_values, allow_new_values=True)
+    assert "to_update2" in to_update["subdict"]
+
+
 def test_recursive_update_negative_unknown_field():
     """Test the 'recursive update' utility, when there are unknown fields."""
     # here we try to update an integer with a boolean - it raises error.
@@ -396,3 +418,173 @@ def test_ensure_dir():
 
         with pytest.raises(AEAEnforceError):
             ensure_dir(file_path)
+
+
+class BaseTestCertRequestError:
+    """Test errors when instantiating a CertRequest object."""
+
+    PUBLIC_KEY = "a_public_key"
+    IDENTIFIER = "an_identifier"
+    LEDGER_ID = "a_ledger_id"
+    NOT_BEFORE = "2020-01-01"
+    NOT_AFTER = "2020-01-02"
+    PATH = "some/path"
+    ERROR_MESSAGE_PATTERN = ""
+
+    def test_error(self):
+        """Test error during instantiation.."""
+        with pytest.raises(ValueError, match=self.ERROR_MESSAGE_PATTERN):
+            CertRequest(
+                self.PUBLIC_KEY,
+                self.IDENTIFIER,
+                self.LEDGER_ID,
+                self.NOT_BEFORE,
+                self.NOT_AFTER,
+                self.PATH,
+            )
+
+
+class TestCertRequestBadPublicKey(BaseTestCertRequestError):
+    """Test instantiation of CertRequest class with bad public key."""
+
+    PUBLIC_KEY = "0a_bad_identifier"
+    ERROR_MESSAGE_PATTERN = "Public key field '0a_bad_identifier' is neither a valid identifier nor an address."
+
+
+class TestCertRequestBadIdentifier(BaseTestCertRequestError):
+    """Test instantiation of CertRequest class with bad identifier."""
+
+    IDENTIFIER = "0bad_identifier"
+    ERROR_MESSAGE_PATTERN = (
+        "Value 0bad_identifier does not match the regular expression.*"
+    )
+
+
+class TestCertRequestBadLedgerId(BaseTestCertRequestError):
+    """Test instantiation of CertRequest class with bad ledger id."""
+
+    LEDGER_ID = "0bad_identifier"
+    ERROR_MESSAGE_PATTERN = (
+        "Value 0bad_identifier does not match the regular expression.*"
+    )
+
+
+class TestCertRequestBadNotBefore(BaseTestCertRequestError):
+    """Test instantiation of CertRequest class with bad not_before date."""
+
+    NOT_BEFORE = "bad-formatted-date"
+    ERROR_MESSAGE_PATTERN = (
+        "time data 'bad-formatted-date' does not match format '%Y-%m-%d'"
+    )
+
+
+class TestCertRequestBadNotAfter(BaseTestCertRequestError):
+    """Test instantiation of CertRequest class with bad not_after date."""
+
+    NOT_AFTER = "bad-formatted-date"
+    ERROR_MESSAGE_PATTERN = (
+        "time data 'bad-formatted-date' does not match format '%Y-%m-%d'"
+    )
+
+
+class TestCertRequestInconsistentDates(BaseTestCertRequestError):
+    """Test instantiation of CertRequest class when not_before >= not_after"""
+
+    NOT_BEFORE = "1954-06-07"
+    NOT_AFTER = "1900-01-01"
+    ERROR_MESSAGE_PATTERN = r"Inconsistent certificate validity period: 'not_before' field '1954-06-07' is not before than 'not_after' field '1900-01-01'"
+
+
+class BaseTestCertRequestInstantiation:
+    """Test (successful) instantiation of CertRequest class."""
+
+    PUBLIC_KEY: Optional[str] = ""
+    EXPECTED_PUBLIC_KEY: Optional[str] = ""
+    EXPECTED_KEY_IDENTIFIER: Optional[str] = ""
+
+    @classmethod
+    def setup_class(cls):
+        """Set up class."""
+        cls.expected_public_key = cls.PUBLIC_KEY
+        cls.expected_identifier = "identifier"
+        cls.expected_ledger_id = "ledger_id"
+        cls.not_before = "2020-01-01"
+        cls.not_after = "2020-01-02"
+        cls.expected_path = os.path.abspath("some/path")
+        cls.cert_request = CertRequest(
+            cls.expected_public_key,
+            cls.expected_identifier,
+            cls.expected_ledger_id,
+            cls.not_before,
+            cls.not_after,
+            cls.expected_path,
+        )
+
+    def test_instantiation(self):
+        """Test instantiation."""
+        assert self.cert_request.public_key == self.EXPECTED_PUBLIC_KEY
+        assert self.cert_request.key_identifier == self.EXPECTED_KEY_IDENTIFIER
+        assert self.cert_request.identifier == self.expected_identifier
+        assert self.cert_request.ledger_id == self.expected_ledger_id
+
+        expected_not_before = datetime.datetime(
+            2020, 1, 1, 0, 0, 0, 0, datetime.timezone.utc
+        )
+        assert self.cert_request.not_before == expected_not_before
+
+        expected_not_after = datetime.datetime(
+            2020, 1, 2, 0, 0, 0, 0, datetime.timezone.utc
+        )
+        assert self.cert_request.not_after == expected_not_after
+
+        assert self.cert_request.not_before_string == expected_not_before.strftime(
+            "%Y-%m-%d"
+        )
+        assert self.cert_request.not_after_string == expected_not_after.strftime(
+            "%Y-%m-%d"
+        )
+        assert self.cert_request.get_message("some_key")
+
+        assert self.cert_request.save_path == Path(self.expected_path)
+
+    def test_from_to_json(self):
+        """Test from-to json methods."""
+        assert self.cert_request == self.cert_request.from_json(self.cert_request.json)
+
+
+class TestCertRequestInstantiationWithKeyIdentifier(BaseTestCertRequestInstantiation):
+    """Test (successful) instantiation of CertRequest class."""
+
+    PUBLIC_KEY = "public_key"
+    EXPECTED_PUBLIC_KEY = None
+    EXPECTED_KEY_IDENTIFIER = PUBLIC_KEY
+
+
+class TestCertRequestInstantiationWithKeyHex(BaseTestCertRequestInstantiation):
+    """Test (successful) instantiation of CertRequest class."""
+
+    PUBLIC_KEY = "0xABCDEF12345"
+    EXPECTED_PUBLIC_KEY = "0xABCDEF12345"
+    EXPECTED_KEY_IDENTIFIER = None
+
+
+def test_compute_specifier_from_version():
+    """Test function 'compute_specifier_from_version'."""
+
+    version = "0.1.5"
+    expected_range = ">=0.1.0, <0.2.0"
+    assert expected_range == compute_specifier_from_version(Version(version))
+
+    version = "1.1.5"
+    expected_range = ">=1.1.0, <1.2.0"
+    assert expected_range == compute_specifier_from_version(Version(version))
+
+
+def test_dict_to_path_value():
+    """Test dict_to_path_value."""
+    path_values = {
+        tuple(path): value
+        for path, value in dict_to_path_value({"a": 12, "b": {"c": 1}})
+    }
+    assert path_values.get(("a",)) == 12
+    assert path_values.get(("b", "c")) == 1
