@@ -19,6 +19,7 @@
 """This test module contains the integration test for the tac skills."""
 
 import datetime
+import json
 import uuid
 from random import uniform
 
@@ -29,18 +30,17 @@ from aea.test_tools.test_cases import AEATestCaseMany
 from packages.fetchai.connections.p2p_libp2p.connection import LIBP2P_SUCCESS_MESSAGE
 
 from tests.conftest import (
-    COSMOS,
-    COSMOS_PRIVATE_KEY_FILE_CONNECTION,
     ETHEREUM,
     ETHEREUM_PRIVATE_KEY_FILE,
     FETCHAI,
     FETCHAI_PRIVATE_KEY_FILE,
+    FETCHAI_PRIVATE_KEY_FILE_CONNECTION,
     FUNDED_ETH_PRIVATE_KEY_1,
     FUNDED_ETH_PRIVATE_KEY_2,
     FUNDED_ETH_PRIVATE_KEY_3,
     MAX_FLAKY_RERUNS_ETH,
     MAX_FLAKY_RERUNS_INTEGRATION,
-    NON_FUNDED_COSMOS_PRIVATE_KEY_1,
+    NON_FUNDED_FETCHAI_PRIVATE_KEY_1,
     NON_GENESIS_CONFIG,
     NON_GENESIS_CONFIG_TWO,
     UseGanache,
@@ -71,7 +71,7 @@ class TestTacSkills(AEATestCaseMany):
         )
 
         default_routing = {
-            "fetchai/oef_search:0.11.0": "fetchai/soef:0.14.0",
+            "fetchai/oef_search:0.12.0": "fetchai/soef:0.15.0",
         }
 
         # generate random location
@@ -85,18 +85,18 @@ class TestTacSkills(AEATestCaseMany):
 
         # prepare tac controller for test
         self.set_agent_context(tac_controller_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.13.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
-        self.add_item("connection", "fetchai/soef:0.14.0")
-        self.remove_item("connection", "fetchai/stub:0.13.0")
-        self.add_item("skill", "fetchai/tac_control:0.13.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.14.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.14.0")
+        self.add_item("connection", "fetchai/soef:0.15.0")
+        self.remove_item("connection", "fetchai/stub:0.14.0")
+        self.add_item("skill", "fetchai/tac_control:0.14.0")
         self.set_config("agent.default_ledger", FETCHAI)
         setting_path = "agent.default_routing"
         self.nested_set_config(setting_path, default_routing)
         self.run_install()
 
         diff = self.difference_to_fetched_agent(
-            "fetchai/tac_controller:0.16.0", tac_controller_name
+            "fetchai/tac_controller:0.17.0", tac_controller_name
         )
         assert (
             diff == []
@@ -104,16 +104,16 @@ class TestTacSkills(AEATestCaseMany):
 
         # add keys
         self.generate_private_key(FETCHAI)
-        self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
+        self.generate_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE_CONNECTION)
         self.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
         self.add_private_key(
-            COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
+            FETCHAI, FETCHAI_PRIVATE_KEY_FILE_CONNECTION, connection=True
         )
         self.replace_private_key_in_file(
-            NON_FUNDED_COSMOS_PRIVATE_KEY_1, COSMOS_PRIVATE_KEY_FILE_CONNECTION
+            NON_FUNDED_FETCHAI_PRIVATE_KEY_1, FETCHAI_PRIVATE_KEY_FILE_CONNECTION
         )
         setting_path = "vendor.fetchai.connections.p2p_libp2p.config.ledger_id"
-        self.set_config(setting_path, COSMOS)
+        self.set_config(setting_path, FETCHAI)
 
         # replace location
         setting_path = (
@@ -129,8 +129,8 @@ class TestTacSkills(AEATestCaseMany):
         self.nested_set_config(setting_path, data)
 
         default_routing = {
-            "fetchai/ledger_api:0.8.0": "fetchai/ledger:0.11.0",
-            "fetchai/oef_search:0.11.0": "fetchai/soef:0.14.0",
+            "fetchai/ledger_api:0.9.0": "fetchai/ledger:0.12.0",
+            "fetchai/oef_search:0.12.0": "fetchai/soef:0.15.0",
         }
 
         # prepare agents for test
@@ -139,19 +139,19 @@ class TestTacSkills(AEATestCaseMany):
             (tac_aea_two, NON_GENESIS_CONFIG_TWO),
         ):
             self.set_agent_context(agent_name)
-            self.add_item("connection", "fetchai/p2p_libp2p:0.13.0")
-            self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
-            self.add_item("connection", "fetchai/soef:0.14.0")
-            self.add_item("connection", "fetchai/ledger:0.11.0")
-            self.remove_item("connection", "fetchai/stub:0.13.0")
-            self.add_item("skill", "fetchai/tac_participation:0.14.0")
-            self.add_item("skill", "fetchai/tac_negotiation:0.16.0")
+            self.add_item("connection", "fetchai/p2p_libp2p:0.14.0")
+            self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.14.0")
+            self.add_item("connection", "fetchai/soef:0.15.0")
+            self.add_item("connection", "fetchai/ledger:0.12.0")
+            self.remove_item("connection", "fetchai/stub:0.14.0")
+            self.add_item("skill", "fetchai/tac_participation:0.15.0")
+            self.add_item("skill", "fetchai/tac_negotiation:0.17.0")
             self.set_config("agent.default_ledger", FETCHAI)
             setting_path = "agent.default_routing"
             self.nested_set_config(setting_path, default_routing)
             self.run_install()
             diff = self.difference_to_fetched_agent(
-                "fetchai/tac_participant:0.18.0", agent_name
+                "fetchai/tac_participant:0.19.0", agent_name
             )
             assert (
                 diff == []
@@ -161,10 +161,10 @@ class TestTacSkills(AEATestCaseMany):
 
             # add keys
             self.generate_private_key(FETCHAI)
-            self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
+            self.generate_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE_CONNECTION)
             self.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
             self.add_private_key(
-                COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
+                FETCHAI, FETCHAI_PRIVATE_KEY_FILE_CONNECTION, connection=True
             )
 
             # set p2p configs
@@ -197,6 +197,7 @@ class TestTacSkills(AEATestCaseMany):
         setting_path = "vendor.fetchai.skills.tac_control.models.parameters.args.registration_start_time"
         self.set_config(setting_path, start_time)
         self.run_cli_command("build", cwd=self._get_cwd())
+        self.run_cli_command("issue-certificates", cwd=self._get_cwd())
         tac_controller_process = self.run_agent()
 
         check_strings = (
@@ -206,7 +207,7 @@ class TestTacSkills(AEATestCaseMany):
             LIBP2P_SUCCESS_MESSAGE,
         )
         missing_strings = self.missing_from_output(
-            tac_controller_process, check_strings, timeout=240, is_terminating=False
+            tac_controller_process, check_strings, timeout=30, is_terminating=False
         )
         assert (
             missing_strings == []
@@ -215,10 +216,12 @@ class TestTacSkills(AEATestCaseMany):
         # run two agents (participants)
         self.set_agent_context(tac_aea_one)
         self.run_cli_command("build", cwd=self._get_cwd())
+        self.run_cli_command("issue-certificates", cwd=self._get_cwd())
         tac_aea_one_process = self.run_agent()
 
         self.set_agent_context(tac_aea_two)
         self.run_cli_command("build", cwd=self._get_cwd())
+        self.run_cli_command("issue-certificates", cwd=self._get_cwd())
         tac_aea_two_process = self.run_agent()
 
         check_strings = (
@@ -228,7 +231,7 @@ class TestTacSkills(AEATestCaseMany):
             LIBP2P_SUCCESS_MESSAGE,
         )
         missing_strings = self.missing_from_output(
-            tac_aea_one_process, check_strings, timeout=240, is_terminating=False
+            tac_aea_one_process, check_strings, timeout=30, is_terminating=False
         )
         assert (
             missing_strings == []
@@ -241,7 +244,7 @@ class TestTacSkills(AEATestCaseMany):
             LIBP2P_SUCCESS_MESSAGE,
         )
         missing_strings = self.missing_from_output(
-            tac_aea_two_process, check_strings, timeout=240, is_terminating=False
+            tac_aea_two_process, check_strings, timeout=30, is_terminating=False
         )
         assert (
             missing_strings == []
@@ -326,9 +329,9 @@ class TestTacSkillsContract(AEATestCaseMany, UseGanache):
         )
 
         default_routing = {
-            "fetchai/contract_api:0.9.0": "fetchai/ledger:0.11.0",
-            "fetchai/ledger_api:0.8.0": "fetchai/ledger:0.11.0",
-            "fetchai/oef_search:0.11.0": "fetchai/soef:0.14.0",
+            "fetchai/contract_api:0.10.0": "fetchai/ledger:0.12.0",
+            "fetchai/ledger_api:0.9.0": "fetchai/ledger:0.12.0",
+            "fetchai/oef_search:0.12.0": "fetchai/soef:0.15.0",
         }
 
         # generate random location
@@ -342,19 +345,19 @@ class TestTacSkillsContract(AEATestCaseMany, UseGanache):
 
         # prepare tac controller for test
         self.set_agent_context(tac_controller_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.13.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
-        self.add_item("connection", "fetchai/soef:0.14.0")
-        self.add_item("connection", "fetchai/ledger:0.11.0")
-        self.remove_item("connection", "fetchai/stub:0.13.0")
-        self.add_item("skill", "fetchai/tac_control_contract:0.15.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.14.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.14.0")
+        self.add_item("connection", "fetchai/soef:0.15.0")
+        self.add_item("connection", "fetchai/ledger:0.12.0")
+        self.remove_item("connection", "fetchai/stub:0.14.0")
+        self.add_item("skill", "fetchai/tac_control_contract:0.16.0")
         self.set_config("agent.default_ledger", ETHEREUM)
         setting_path = "agent.default_routing"
         self.nested_set_config(setting_path, default_routing)
         self.run_install()
 
         diff = self.difference_to_fetched_agent(
-            "fetchai/tac_controller_contract:0.18.0", tac_controller_name
+            "fetchai/tac_controller_contract:0.19.0", tac_controller_name
         )
         assert (
             diff == []
@@ -362,19 +365,31 @@ class TestTacSkillsContract(AEATestCaseMany, UseGanache):
 
         # add keys
         self.generate_private_key(ETHEREUM)
-        self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
+        self.generate_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE_CONNECTION)
         self.add_private_key(ETHEREUM, ETHEREUM_PRIVATE_KEY_FILE)
         self.add_private_key(
-            COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
+            FETCHAI, FETCHAI_PRIVATE_KEY_FILE_CONNECTION, connection=True
         )
         self.replace_private_key_in_file(
             FUNDED_ETH_PRIVATE_KEY_1, ETHEREUM_PRIVATE_KEY_FILE
         )
         self.replace_private_key_in_file(
-            NON_FUNDED_COSMOS_PRIVATE_KEY_1, COSMOS_PRIVATE_KEY_FILE_CONNECTION
+            NON_FUNDED_FETCHAI_PRIVATE_KEY_1, FETCHAI_PRIVATE_KEY_FILE_CONNECTION
         )
-        setting_path = "vendor.fetchai.connections.p2p_libp2p.config.ledger_id"
-        self.set_config(setting_path, COSMOS)
+        setting_path = "vendor.fetchai.connections.p2p_libp2p.cert_requests"
+        settings = json.dumps(
+            [
+                {
+                    "identifier": "acn",
+                    "ledger_id": ETHEREUM,
+                    "not_after": "2022-01-01",
+                    "not_before": "2021-01-01",
+                    "public_key": FETCHAI,
+                    "save_path": ".certs/conn_cert.txt",
+                }
+            ]
+        )
+        self.set_config(setting_path, settings, type_="list")
         setting_path = "vendor.fetchai.connections.soef.config.chain_identifier"
         self.set_config(setting_path, ETHEREUM)
         setting_path = "vendor.fetchai.skills.tac_control.is_abstract"
@@ -392,9 +407,9 @@ class TestTacSkillsContract(AEATestCaseMany, UseGanache):
         self.nested_set_config(setting_path, data)
 
         default_routing = {
-            "fetchai/contract_api:0.9.0": "fetchai/ledger:0.11.0",
-            "fetchai/ledger_api:0.8.0": "fetchai/ledger:0.11.0",
-            "fetchai/oef_search:0.11.0": "fetchai/soef:0.14.0",
+            "fetchai/contract_api:0.10.0": "fetchai/ledger:0.12.0",
+            "fetchai/ledger_api:0.9.0": "fetchai/ledger:0.12.0",
+            "fetchai/oef_search:0.12.0": "fetchai/soef:0.15.0",
         }
 
         # prepare agents for test
@@ -403,13 +418,13 @@ class TestTacSkillsContract(AEATestCaseMany, UseGanache):
             (tac_aea_two, NON_GENESIS_CONFIG_TWO, FUNDED_ETH_PRIVATE_KEY_3),
         ):
             self.set_agent_context(agent_name)
-            self.add_item("connection", "fetchai/p2p_libp2p:0.13.0")
-            self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
-            self.add_item("connection", "fetchai/soef:0.14.0")
-            self.add_item("connection", "fetchai/ledger:0.11.0")
-            self.remove_item("connection", "fetchai/stub:0.13.0")
-            self.add_item("skill", "fetchai/tac_participation:0.14.0")
-            self.add_item("skill", "fetchai/tac_negotiation:0.16.0")
+            self.add_item("connection", "fetchai/p2p_libp2p:0.14.0")
+            self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.14.0")
+            self.add_item("connection", "fetchai/soef:0.15.0")
+            self.add_item("connection", "fetchai/ledger:0.12.0")
+            self.remove_item("connection", "fetchai/stub:0.14.0")
+            self.add_item("skill", "fetchai/tac_participation:0.15.0")
+            self.add_item("skill", "fetchai/tac_negotiation:0.17.0")
             self.set_config("agent.default_ledger", ETHEREUM)
             setting_path = "agent.default_routing"
             self.nested_set_config(setting_path, default_routing)
@@ -425,7 +440,7 @@ class TestTacSkillsContract(AEATestCaseMany, UseGanache):
             )
             self.run_install()
             diff = self.difference_to_fetched_agent(
-                "fetchai/tac_participant_contract:0.8.0", agent_name
+                "fetchai/tac_participant_contract:0.9.0", agent_name
             )
             assert (
                 diff == []
@@ -435,20 +450,30 @@ class TestTacSkillsContract(AEATestCaseMany, UseGanache):
 
             # add keys
             self.generate_private_key(ETHEREUM)
-            self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
+            self.generate_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE_CONNECTION)
             self.add_private_key(ETHEREUM, ETHEREUM_PRIVATE_KEY_FILE)
             self.add_private_key(
-                COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
+                FETCHAI, FETCHAI_PRIVATE_KEY_FILE_CONNECTION, connection=True
             )
             self.replace_private_key_in_file(private_key, ETHEREUM_PRIVATE_KEY_FILE)
 
             # set p2p configs
             setting_path = "vendor.fetchai.connections.p2p_libp2p.config"
             self.nested_set_config(setting_path, config)
-            setting_path = "vendor.fetchai.connections.p2p_libp2p.config.ledger_id"
-            self.set_config(setting_path, COSMOS)
-            setting_path = "vendor.fetchai.connections.soef.config.chain_identifier"
-            self.set_config(setting_path, ETHEREUM)
+            setting_path = "vendor.fetchai.connections.p2p_libp2p.cert_requests"
+            settings = json.dumps(
+                [
+                    {
+                        "identifier": "acn",
+                        "ledger_id": ETHEREUM,
+                        "not_after": "2022-01-01",
+                        "not_before": "2021-01-01",
+                        "public_key": FETCHAI,
+                        "save_path": ".certs/conn_cert.txt",
+                    }
+                ]
+            )
+            self.set_config(setting_path, settings, type_="list")
 
             # replace location
             setting_path = (
@@ -466,18 +491,21 @@ class TestTacSkillsContract(AEATestCaseMany, UseGanache):
                 "vendor.fetchai.skills.tac_participation.models.game.args.search_query"
             )
             self.nested_set_config(setting_path, data)
+            setting_path = "vendor.fetchai.connections.soef.config.chain_identifier"
+            self.set_config(setting_path, ETHEREUM)
 
         # run tac controller
         self.set_agent_context(tac_controller_name)
+        self.run_cli_command("build", cwd=self._get_cwd())
+        self.run_cli_command("issue-certificates", cwd=self._get_cwd())
         now = datetime.datetime.now().strftime("%d %m %Y %H:%M")
         now_min = datetime.datetime.strptime(now, "%d %m %Y %H:%M")
         fut = now_min + datetime.timedelta(
-            0, 180
-        )  # we provide 3 minutes time for contract deployment
+            0, 120
+        )  # we provide 2 minutes time for contract deployment
         start_time = fut.strftime("%d %m %Y %H:%M")
         setting_path = "vendor.fetchai.skills.tac_control_contract.models.parameters.args.registration_start_time"
         self.set_config(setting_path, start_time)
-        self.run_cli_command("build", cwd=self._get_cwd())
         tac_controller_process = self.run_agent()
 
         check_strings = (
@@ -499,8 +527,8 @@ class TestTacSkillsContract(AEATestCaseMany, UseGanache):
             "TAC open for registration until:",
         )
         missing_strings = self.missing_from_output(
-            tac_controller_process, check_strings, timeout=240, is_terminating=False
-        )
+            tac_controller_process, check_strings, timeout=180, is_terminating=False
+        )  # we need to wait sufficiently long (at least 2 minutes - see above for deployment)
         assert (
             missing_strings == []
         ), "Strings {} didn't appear in tac_controller output.".format(missing_strings)
@@ -508,10 +536,12 @@ class TestTacSkillsContract(AEATestCaseMany, UseGanache):
         # run two agents (participants)
         self.set_agent_context(tac_aea_one)
         self.run_cli_command("build", cwd=self._get_cwd())
+        self.run_cli_command("issue-certificates", cwd=self._get_cwd())
         tac_aea_one_process = self.run_agent()
 
         self.set_agent_context(tac_aea_two)
         self.run_cli_command("build", cwd=self._get_cwd())
+        self.run_cli_command("issue-certificates", cwd=self._get_cwd())
         tac_aea_two_process = self.run_agent()
 
         check_strings = (
@@ -521,11 +551,14 @@ class TestTacSkillsContract(AEATestCaseMany, UseGanache):
             LIBP2P_SUCCESS_MESSAGE,
             "Start processing messages...",
             "searching for TAC, search_id=",
-            "found the TAC controller. Registering...",
         )
         missing_strings = self.missing_from_output(
-            tac_aea_one_process, check_strings, timeout=240, is_terminating=False
+            tac_aea_one_process, check_strings, timeout=30, is_terminating=False
         )
+        check_strings = ("found the TAC controller. Registering...",)
+        missing_strings = self.missing_from_output(
+            tac_aea_one_process, check_strings, timeout=60, is_terminating=False
+        )  # we need to wait sufficiently long (at least 1 minutes - for registration)
         assert (
             missing_strings == []
         ), "Strings {} didn't appear in tac_aea_one output.".format(missing_strings)
@@ -540,7 +573,7 @@ class TestTacSkillsContract(AEATestCaseMany, UseGanache):
             "found the TAC controller. Registering...",
         )
         missing_strings = self.missing_from_output(
-            tac_aea_two_process, check_strings, timeout=240, is_terminating=False
+            tac_aea_two_process, check_strings, timeout=30, is_terminating=False
         )
         assert (
             missing_strings == []
@@ -588,8 +621,8 @@ class TestTacSkillsContract(AEATestCaseMany, UseGanache):
             "received match_accept_w_inform from",
             "sending propose to",
             "sending accept to",
-            "requesting batch transaction hash, sending get_raw_message to fetchai/erc1155:0.13.0, message=",
-            "requesting batch atomic swap transaction, sending get_raw_transaction to fetchai/erc1155:0.13.0, message=",
+            "requesting batch transaction hash, sending get_raw_message to fetchai/erc1155:0.14.0, message=",
+            "requesting batch atomic swap transaction, sending get_raw_transaction to fetchai/erc1155:0.14.0, message=",
             "received raw transaction=",
             "received raw message=",
             "proposing the transaction to the decision maker. Waiting for confirmation ...",
@@ -621,8 +654,8 @@ class TestTacSkillsContract(AEATestCaseMany, UseGanache):
             "received match_accept_w_inform from",
             "sending propose to",
             "sending accept to",
-            "requesting batch transaction hash, sending get_raw_message to fetchai/erc1155:0.13.0, message=",
-            "requesting batch atomic swap transaction, sending get_raw_transaction to fetchai/erc1155:0.13.0, message=",
+            "requesting batch transaction hash, sending get_raw_message to fetchai/erc1155:0.14.0, message=",
+            "requesting batch atomic swap transaction, sending get_raw_transaction to fetchai/erc1155:0.14.0, message=",
             "received raw transaction=",
             "received raw message=",
             "proposing the transaction to the decision maker. Waiting for confirmation ...",
