@@ -27,12 +27,11 @@ from aea.test_tools.test_cases import AEATestCaseMany
 from packages.fetchai.connections.p2p_libp2p.connection import LIBP2P_SUCCESS_MESSAGE
 
 from tests.conftest import (
-    COSMOS,
-    COSMOS_PRIVATE_KEY_FILE_CONNECTION,
     FETCHAI,
     FETCHAI_PRIVATE_KEY_FILE,
+    FETCHAI_PRIVATE_KEY_FILE_CONNECTION,
     MAX_FLAKY_RERUNS_INTEGRATION,
-    NON_FUNDED_COSMOS_PRIVATE_KEY_1,
+    NON_FUNDED_FETCHAI_PRIVATE_KEY_1,
     NON_GENESIS_CONFIG,
     wait_for_localhost_ports_to_close,
 )
@@ -53,8 +52,8 @@ class TestThermometerSkill(AEATestCaseMany):
         self.create_agents(thermometer_aea_name, thermometer_client_aea_name)
 
         default_routing = {
-            "fetchai/ledger_api:0.8.0": "fetchai/ledger:0.11.0",
-            "fetchai/oef_search:0.11.0": "fetchai/soef:0.14.0",
+            "fetchai/ledger_api:0.9.0": "fetchai/ledger:0.12.0",
+            "fetchai/oef_search:0.12.0": "fetchai/soef:0.15.0",
         }
 
         # generate random location
@@ -65,12 +64,12 @@ class TestThermometerSkill(AEATestCaseMany):
 
         # add packages for agent one and run it
         self.set_agent_context(thermometer_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.13.0")
-        self.add_item("connection", "fetchai/soef:0.14.0")
-        self.remove_item("connection", "fetchai/stub:0.13.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
-        self.add_item("connection", "fetchai/ledger:0.11.0")
-        self.add_item("skill", "fetchai/thermometer:0.17.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.14.0")
+        self.add_item("connection", "fetchai/soef:0.15.0")
+        self.remove_item("connection", "fetchai/stub:0.14.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.14.0")
+        self.add_item("connection", "fetchai/ledger:0.12.0")
+        self.add_item("skill", "fetchai/thermometer:0.18.0")
         setting_path = (
             "vendor.fetchai.skills.thermometer.models.strategy.args.is_ledger_tx"
         )
@@ -81,16 +80,16 @@ class TestThermometerSkill(AEATestCaseMany):
 
         # add keys
         self.generate_private_key(FETCHAI)
-        self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
+        self.generate_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE_CONNECTION)
         self.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
         self.add_private_key(
-            COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
+            FETCHAI, FETCHAI_PRIVATE_KEY_FILE_CONNECTION, connection=True
         )
         self.replace_private_key_in_file(
-            NON_FUNDED_COSMOS_PRIVATE_KEY_1, COSMOS_PRIVATE_KEY_FILE_CONNECTION
+            NON_FUNDED_FETCHAI_PRIVATE_KEY_1, FETCHAI_PRIVATE_KEY_FILE_CONNECTION
         )
         setting_path = "vendor.fetchai.connections.p2p_libp2p.config.ledger_id"
-        self.set_config(setting_path, COSMOS)
+        self.set_config(setting_path, FETCHAI)
 
         # replace location
         setting_path = "vendor.fetchai.skills.thermometer.models.strategy.args.location"
@@ -98,12 +97,12 @@ class TestThermometerSkill(AEATestCaseMany):
 
         # add packages for agent two and run it
         self.set_agent_context(thermometer_client_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.13.0")
-        self.add_item("connection", "fetchai/soef:0.14.0")
-        self.remove_item("connection", "fetchai/stub:0.13.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
-        self.add_item("connection", "fetchai/ledger:0.11.0")
-        self.add_item("skill", "fetchai/thermometer_client:0.17.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.14.0")
+        self.add_item("connection", "fetchai/soef:0.15.0")
+        self.remove_item("connection", "fetchai/stub:0.14.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.14.0")
+        self.add_item("connection", "fetchai/ledger:0.12.0")
+        self.add_item("skill", "fetchai/thermometer_client:0.18.0")
         setting_path = (
             "vendor.fetchai.skills.thermometer_client.models.strategy.args.is_ledger_tx"
         )
@@ -114,10 +113,10 @@ class TestThermometerSkill(AEATestCaseMany):
 
         # add keys
         self.generate_private_key(FETCHAI)
-        self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
+        self.generate_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE_CONNECTION)
         self.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
         self.add_private_key(
-            COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
+            FETCHAI, FETCHAI_PRIVATE_KEY_FILE_CONNECTION, connection=True
         )
 
         # set p2p configs
@@ -133,6 +132,7 @@ class TestThermometerSkill(AEATestCaseMany):
         # run AEAs
         self.set_agent_context(thermometer_aea_name)
         self.run_cli_command("build", cwd=self._get_cwd())
+        self.run_cli_command("issue-certificates", cwd=self._get_cwd())
         thermometer_aea_process = self.run_agent()
 
         check_strings = (
@@ -142,7 +142,7 @@ class TestThermometerSkill(AEATestCaseMany):
             LIBP2P_SUCCESS_MESSAGE,
         )
         missing_strings = self.missing_from_output(
-            thermometer_aea_process, check_strings, timeout=240, is_terminating=False
+            thermometer_aea_process, check_strings, timeout=30, is_terminating=False
         )
         assert (
             missing_strings == []
@@ -150,6 +150,7 @@ class TestThermometerSkill(AEATestCaseMany):
 
         self.set_agent_context(thermometer_client_aea_name)
         self.run_cli_command("build", cwd=self._get_cwd())
+        self.run_cli_command("issue-certificates", cwd=self._get_cwd())
         thermometer_client_aea_process = self.run_agent()
 
         check_strings = (
@@ -227,8 +228,8 @@ class TestThermometerSkillFetchaiLedger(AEATestCaseMany):
         self.create_agents(thermometer_aea_name, thermometer_client_aea_name)
 
         default_routing = {
-            "fetchai/ledger_api:0.8.0": "fetchai/ledger:0.11.0",
-            "fetchai/oef_search:0.11.0": "fetchai/soef:0.14.0",
+            "fetchai/ledger_api:0.9.0": "fetchai/ledger:0.12.0",
+            "fetchai/oef_search:0.12.0": "fetchai/soef:0.15.0",
         }
 
         # generate random location
@@ -239,18 +240,18 @@ class TestThermometerSkillFetchaiLedger(AEATestCaseMany):
 
         # add packages for agent one and run it
         self.set_agent_context(thermometer_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.13.0")
-        self.add_item("connection", "fetchai/soef:0.14.0")
-        self.remove_item("connection", "fetchai/stub:0.13.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
-        self.add_item("connection", "fetchai/ledger:0.11.0")
-        self.add_item("skill", "fetchai/thermometer:0.17.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.14.0")
+        self.add_item("connection", "fetchai/soef:0.15.0")
+        self.remove_item("connection", "fetchai/stub:0.14.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.14.0")
+        self.add_item("connection", "fetchai/ledger:0.12.0")
+        self.add_item("skill", "fetchai/thermometer:0.18.0")
         setting_path = "agent.default_routing"
         self.nested_set_config(setting_path, default_routing)
         self.run_install()
 
         diff = self.difference_to_fetched_agent(
-            "fetchai/thermometer_aea:0.17.0", thermometer_aea_name
+            "fetchai/thermometer_aea:0.18.0", thermometer_aea_name
         )
         assert (
             diff == []
@@ -258,16 +259,16 @@ class TestThermometerSkillFetchaiLedger(AEATestCaseMany):
 
         # add keys
         self.generate_private_key(FETCHAI)
-        self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
+        self.generate_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE_CONNECTION)
         self.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
         self.add_private_key(
-            COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
+            FETCHAI, FETCHAI_PRIVATE_KEY_FILE_CONNECTION, connection=True
         )
         self.replace_private_key_in_file(
-            NON_FUNDED_COSMOS_PRIVATE_KEY_1, COSMOS_PRIVATE_KEY_FILE_CONNECTION
+            NON_FUNDED_FETCHAI_PRIVATE_KEY_1, FETCHAI_PRIVATE_KEY_FILE_CONNECTION
         )
         setting_path = "vendor.fetchai.connections.p2p_libp2p.config.ledger_id"
-        self.set_config(setting_path, COSMOS)
+        self.set_config(setting_path, FETCHAI)
 
         # replace location
         setting_path = "vendor.fetchai.skills.thermometer.models.strategy.args.location"
@@ -275,18 +276,18 @@ class TestThermometerSkillFetchaiLedger(AEATestCaseMany):
 
         # add packages for agent two and run it
         self.set_agent_context(thermometer_client_aea_name)
-        self.add_item("connection", "fetchai/p2p_libp2p:0.13.0")
-        self.add_item("connection", "fetchai/soef:0.14.0")
-        self.remove_item("connection", "fetchai/stub:0.13.0")
-        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.13.0")
-        self.add_item("connection", "fetchai/ledger:0.11.0")
-        self.add_item("skill", "fetchai/thermometer_client:0.17.0")
+        self.add_item("connection", "fetchai/p2p_libp2p:0.14.0")
+        self.add_item("connection", "fetchai/soef:0.15.0")
+        self.remove_item("connection", "fetchai/stub:0.14.0")
+        self.set_config("agent.default_connection", "fetchai/p2p_libp2p:0.14.0")
+        self.add_item("connection", "fetchai/ledger:0.12.0")
+        self.add_item("skill", "fetchai/thermometer_client:0.18.0")
         setting_path = "agent.default_routing"
         self.nested_set_config(setting_path, default_routing)
         self.run_install()
 
         diff = self.difference_to_fetched_agent(
-            "fetchai/thermometer_client:0.18.0", thermometer_client_aea_name
+            "fetchai/thermometer_client:0.19.0", thermometer_client_aea_name
         )
         assert (
             diff == []
@@ -294,10 +295,10 @@ class TestThermometerSkillFetchaiLedger(AEATestCaseMany):
 
         # add keys
         self.generate_private_key(FETCHAI)
-        self.generate_private_key(COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION)
+        self.generate_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE_CONNECTION)
         self.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
         self.add_private_key(
-            COSMOS, COSMOS_PRIVATE_KEY_FILE_CONNECTION, connection=True
+            FETCHAI, FETCHAI_PRIVATE_KEY_FILE_CONNECTION, connection=True
         )
 
         # fund key
@@ -316,6 +317,7 @@ class TestThermometerSkillFetchaiLedger(AEATestCaseMany):
         # run AEAs
         self.set_agent_context(thermometer_aea_name)
         self.run_cli_command("build", cwd=self._get_cwd())
+        self.run_cli_command("issue-certificates", cwd=self._get_cwd())
         thermometer_aea_process = self.run_agent()
 
         check_strings = (
@@ -325,7 +327,7 @@ class TestThermometerSkillFetchaiLedger(AEATestCaseMany):
             LIBP2P_SUCCESS_MESSAGE,
         )
         missing_strings = self.missing_from_output(
-            thermometer_aea_process, check_strings, timeout=240, is_terminating=False
+            thermometer_aea_process, check_strings, timeout=30, is_terminating=False
         )
         assert (
             missing_strings == []
@@ -333,6 +335,7 @@ class TestThermometerSkillFetchaiLedger(AEATestCaseMany):
 
         self.set_agent_context(thermometer_client_aea_name)
         self.run_cli_command("build", cwd=self._get_cwd())
+        self.run_cli_command("issue-certificates", cwd=self._get_cwd())
         thermometer_client_aea_process = self.run_agent()
 
         check_strings = (
@@ -344,7 +347,7 @@ class TestThermometerSkillFetchaiLedger(AEATestCaseMany):
         missing_strings = self.missing_from_output(
             thermometer_client_aea_process,
             check_strings,
-            timeout=240,
+            timeout=30,
             is_terminating=False,
         )
         assert (
